@@ -20,11 +20,11 @@ OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 SOFTWARE.
 """
 
-__Version__ = '0.0.1'
+__Version__ = '0.0.3'
 __Title__ = 'ThemeTkinter'
 __Author__ = 'Xiaocaicai'
 __Author_Email__ = 'xiaocaicai_email@sina.com'
-__Description__ = 'With beautiful theme tkinter package..'
+__Description__ = 'With beautiful theme tkinter package.'
 __Url__ = 'https://github.com/xiaocaicai-github/ThemeTkinter/'
 
 from ThemeTkinter.Core import Window
